Module database_sync_operations

Module database_sync_operations 

Structs

LogicalReplayApplyStats
MutexSlot
PulledPage
PulledPages
SyncEngineIoStats
SyncOperationCtx

Enums

PullUpdatesV1Result
WalPushResult

Constants

ENCRYPTION_KEY_HEADER
HTTP header key for the encryption key, for the encrypted Turso Cloud databases
PAGE_SIZE
TURSO_SYNC_CREATE_TABLE
TURSO_SYNC_INSERT_LAST_CHANGE_ID
TURSO_SYNC_TABLE_NAME
TURSO_SYNC_UPDATE_LAST_CHANGE_ID
TURSO_SYNC_UPSERT_LAST_CHANGE_ID
WAL_FRAME_HEADER
WAL_FRAME_SIZE
WAL_HEADER

Functions

apply_logical_transactions_file_without_commit_excluding_client_txns_with_table_map_and_stats
apply_transformation
bootstrap_db_file
bootstrap_db_file_legacy
bootstrap_db_file_v1
checkpoint_wal_file
connect_untracked
count_local_changes
db_bootstrap
Bootstrap multiple DB files from latest generation from remote
decode_raw_mvcc_logical_log_to_file
ensure_sync_last_change_id_table
Ensures the local high-water mark table exists and publishes schema changes.
fetch_last_change_id
has_table
logical_txn_to_tape_operations
max_local_change_id
pull_pages_v1
Pull pages from remote, pages slice must be non-empty
pull_updates_v1
Pulls V1 updates as either page frames or raw MVCC logical-log bytes.
push_logical_changes
read_cdc_sequence_watermark
Read the CDC change-id sequence watermark: the first change id that is NOT yet safe for the push loop to consume.
read_last_change_id
read_logical_replay_table_map
Rebuilds the portable logical-replay table identity map from the current local schema. This is used after page-based apply paths, where no logical schema identity operations are decoded but future logical pulls may depend on an existing map.
read_varint
read_wal_salt
reset_wal_file
sync_file
fsync the given file, yielding on the coro until the sync completion finishes.
update_last_change_id
wait_all_results
wait_ok_status
wait_proto_message
wait_status
wal_apply_from_file
wal_pull_to_file
wal_pull_to_file_legacy
Pull updates from remote to the separate file
wal_pull_to_file_v1
Pull updates from remote to the separate file
wal_push
Push frame range [start_frame..end_frame) to the remote Returns baton for WAL remote-session in case of success Returns Error::DatabaseSyncEngineConflict in case of frame conflict at remote side