pub struct PullUpdatesReqProtoBody {
pub encoding: i32,
pub server_revision: String,
pub client_revision: String,
pub long_poll_timeout_ms: u32,
pub server_pages_selector: Bytes,
pub server_query_selector: String,
pub client_pages: Bytes,
}Fields
encoding: i32requested encoding of the pages
server_revision: Stringrevision of the requested pages on server side; can be None - in which case server will pick latest revision
client_revision: Stringclient revision
long_poll_timeout_ms: u32timeout to wait for new changes before returning empty response; used only if client_revision is set and server_revision is not
server_pages_selector: Bytesserver pages to select for sending; empty set will be interpreted as request for all pages if not empty - then server_pages_selector holds bytes for RoaringBitmap with bits set for pages to return
server_query_selector: Stringserver query which select pages for sending
client_pages: Bytesclient pages
Implementations
Sourceimpl PullUpdatesReqProtoBody
impl PullUpdatesReqProtoBody
Sourcepub fn encoding(&self) -> PageUpdatesEncodingReq
pub fn encoding(&self) -> PageUpdatesEncodingReq
Returns the enum value of encoding, or the default if the field is set to an invalid enum value.
Sourcepub fn set_encoding(&mut self, value: PageUpdatesEncodingReq)
pub fn set_encoding(&mut self, value: PageUpdatesEncodingReq)
Sets encoding to the provided enum value.