Structs
Enums
Constants
- ENCRYPTION_
KEY_ HEADER - HTTP header key for the encryption key, for the encrypted Turso Cloud databases
- PAGE_
SIZE - TURSO_
SYNC_ CREATE_ TABLE - TURSO_
SYNC_ INSERT_ LAST_ CHANGE_ ID - TURSO_
SYNC_ TABLE_ NAME - TURSO_
SYNC_ UPDATE_ LAST_ CHANGE_ ID - TURSO_
SYNC_ UPSERT_ LAST_ CHANGE_ ID - WAL_
FRAME_ HEADER - WAL_
FRAME_ SIZE - WAL_
HEADER
Functions
- apply_
logical_ transactions_ file_ without_ commit_ excluding_ client_ txns_ with_ table_ map_ and_ stats - apply_
transformation - bootstrap_
db_ file - bootstrap_
db_ file_ legacy - bootstrap_
db_ file_ v1 - checkpoint_
wal_ file - connect_
untracked - count_
local_ changes - db_
bootstrap - Bootstrap multiple DB files from latest generation from remote
- decode_
raw_ mvcc_ logical_ log_ to_ file - ensure_
sync_ last_ change_ id_ table - Ensures the local high-water mark table exists and publishes schema changes.
- fetch_
last_ change_ id - has_
table - logical_
txn_ to_ tape_ operations - max_
local_ change_ id - pull_
pages_ v1 - Pull pages from remote, pages slice must be non-empty
- pull_
updates_ v1 - Pulls V1 updates as either page frames or raw MVCC logical-log bytes.
- push_
logical_ changes - read_
cdc_ sequence_ watermark - Read the CDC change-id sequence watermark: the first change id that is NOT yet safe for the push loop to consume.
- read_
last_ change_ id - read_
logical_ replay_ table_ map - Rebuilds the portable logical-replay table identity map from the current local schema. This is used after page-based apply paths, where no logical schema identity operations are decoded but future logical pulls may depend on an existing map.
- read_
varint - read_
wal_ salt - reset_
wal_ file - sync_
file - fsync the given file, yielding on the coro until the sync completion finishes.
- update_
last_ change_ id - wait_
all_ results - wait_
ok_ status - wait_
proto_ message - wait_
status - wal_
apply_ from_ file - wal_
pull_ to_ file - wal_
pull_ to_ file_ legacy - Pull updates from remote to the separate file
- wal_
pull_ to_ file_ v1 - Pull updates from remote to the separate file
- wal_
push - Push frame range [start_frame..end_frame) to the remote Returns baton for WAL remote-session in case of success Returns Error::DatabaseSyncEngineConflict in case of frame conflict at remote side